@@ -5,7 +5,6 @@ OpaqueKey abstract classes for edx-platform object types (courses, definitions,
 import json
 from abc import abstractmethod, abstractproperty
 import warnings
-from six import text_type
 
 from opaque_keys import OpaqueKey
 
@@ -298,8 +297,8 @@ class i4xEncoder(json.JSONEncoder):  # pylint: disable=invalid-name
     """
     def default(self, key):  # pylint: disable=arguments-differ, method-hidden
         if isinstance(key, OpaqueKey):
-            return text_type(key)
-        super(i4xEncoder, self).default(key)
+            return str(key)
+        super().default(key)
         return None
 
 
