@@ -4,7 +4,6 @@
 
 from functools import singledispatch, update_wrapper
 import string
-from six import text_type
 
 from hypothesis import strategies, assume
 from hypothesis.strategies._internal.core import cacheable
@@ -143,7 +142,7 @@ def _aside_v1_exclusions(draw, strategy):
     AsideDefinitionKeyV1 or AsideUsageKeyV1.
     """
     key = draw(strategy)
-    serialized = text_type(key)
+    serialized = str(key)
     assume('::' not in serialized)
     assume(not serialized.endswith(':'))
     return key
